{% extends "base.html" %}

{% block title %}Forum{% endblock title %}

{% block content %}
    {% block forum_nav %}{% endblock forum_nav %}
    {% block forum_content %}{% endblock forum_content %}
{% endblock content %}
